#!/bin/sh

FILESYSTEM=hda
PART1=$FILESYSTEM"1"
PART3=$FILESYSTEM"3"

IMAGE=/mnt/$PART3/upgrade/reboot_update/image/root_fs_image.tar.gz
TARGETDIR=/mnt/$PART1/

STARTLOGINFO="<update cat=\"log\" level=\"info\">"
STARTLOGERROR="<update cat=\"log\" level=\"error\">"
ENDLOGINFO="</update>"

NO_ERROR=0
LOW_ERROR=1
FATAL_ERROR=2

RET_ERROR=$NO_ERROR

cleanup ()
{
  cd /
  sync
  umount $TARGETDIR

  exit $RET_ERROR
}

cd /mnt/hda3/upgrade/reboot_update

if [ $? -ne 0 ];then
  echo $STARTLOGERROR"  failed to install new OS: reboot_update dir not found"$ENDLOGINFO
  RET_ERROR=$FATAL_ERROR
  cleanup
fi

#reformat the rootfs partition
echo $STARTLOGINFO"  reformating the root partition"$ENDLOGINFO
mkfs.ext3 /dev/$PART1 2>&1 >/dev/null
if [ $? -ne 0 ];then
  echo $STARTLOGERROR"  failed to install new OS: mkfs failed"$ENDLOGINFO
  RET_ERROR=$FATAL_ERROR
  cleanup
fi

e2fsck -p -f /dev/$PART1
if [ $? -ne 0 ];then
  e2fsck -p -f /dev/$PART1
  if [ $? -ne 0 ];then
    e2fsck -p -f /dev/$PART1
  fi
fi

mount /dev/$PART1 $TARGETDIR
if [ $? -ne 0 ];then
  echo $STARTLOGERROR"  failed to install new OS: mount /dev/$PART1 failed"$ENDLOGINFO
  RET_ERROR=$FATAL_ERROR
  cleanup
fi

#repopulate the rootfs partition
echo $STARTLOGINFO"  repopulating the root partion"$ENDLOGINFO
cd $TARGETDIR
tar -xzf $IMAGE
if [ $? -ne 0 ];then
  echo $STARTLOGERROR"  failed to install new OS: extract failed"$ENDLOGINFO
  RET_ERROR=2
fi

cleanup