#!/bin/sh

NO_ERROR=0
LOW_ERROR=1
FATAL_ERROR=2

RET_ERROR=0

STARTLOGINFO="<update cat=\"log\" level=\"info\">"
STARTLOGERROR="<update cat=\"log\" level=\"error\">"
ENDLOGINFO="</update>"

echo $STARTLOGINFO"  installing new software"$ENDLOGINFO

IMAGE=`pwd`/image/application_image.tar.gz
TARGETDIR=/usr/local
if [ -f /bin/lsof ]; then
  LSOF=/bin/lsof
else
  LSOF=`pwd`/lsof
  chmod +x $LSOF
fi

#stop the application
echo $STARTLOGINFO"  stopping the application"$ENDLOGINFO
/etc/init.d/S90dctp stop
sleep 10

#reformat the application partition
echo $STARTLOGINFO"  reformating the application partition"$ENDLOGINFO
umount $TARGETDIR
if [ $? -ne 0 ];then
  #umount failed, check for open files on /usr/local
  $LSOF |grep $TARGETDIR
  if [ $? -ne 1 ];then
    #some applications have open files on /usr/local. Let's kill them all!
    $LSOF | grep $TARGETDIR | awk '{print $2}' | xargs kill -9
    sleep 5
  fi
  #try again...
  umount $TARGETDIR
  if [ $? -ne 0 ];then
    #failed again. fatal error
    echo $STARTLOGERROR"  failed to unmount filesystem"$ENDLOGINFO
    echo $STARTLOGINFO"  restarting the application"$ENDLOGINFO
    /etc/init.d/S90dctp start

    exit $FATAL_ERROR
  fi
fi

mkfs.ext3 /dev/hda2
e2fsck -p -f /dev/hda2
mount /dev/hda2 $TARGETDIR

#repopulate the application partion
echo $STARTLOGINFO"  repopulating the application partion"$ENDLOGINFO
cd $TARGETDIR
tar -xzf $IMAGE
RET_ERROR=$?
chown -R root:root $TARGETDIR

#restart the application
echo $STARTLOGINFO"  restarting the application"$ENDLOGINFO
/etc/init.d/S90dctp start

if [ $RET_ERROR -ne 0 ];then
  echo $STARTLOGERROR"  failed to install new software"$ENDLOGINFO
  RET_ERROR=$FATAL_ERROR
fi

exit $RET_ERROR